@@ -7,15 +7,14 @@ class Marcas(FipeApi):
 
     def __init__(self):
         super().__init__()
-        self.endpoint_url = UrlUtil().make_url(self.base_url, ['ConsultarMarcas'])
 
-    def get_marcas(self, codigoTabelaReferencia, codigoTipoVeiculo):
+    def get_marcas(self, codigoTipoVeiculo):
         try:
             logging.info('listing FIPE Brands...')
+            self.endpoint_url = UrlUtil().make_url(self.base_url, [codigoTipoVeiculo, 'brands'])
             res = self.call_request(
-                http_method=HTTPMethod.POST,
-                request_url=self.endpoint_url,
-                payload=self.create_payload(codigoTabelaReferencia, codigoTipoVeiculo)
+                http_method=HTTPMethod.GET,
+                request_url=self.endpoint_url
             )
             return jsonpickle.decode(res)
         except:
